@@ -72,6 +72,7 @@ class MPRester:
     electronic_structure_dos: DosRester
     oxidation_states: OxidationStatesRester
     provenance: ProvenanceRester
+    bonds: BondsRester
     _user_settings: UserSettingsRester
     _general_store: GeneralStoreRester
 
@@ -364,9 +365,7 @@ class MPRester:
         )
 
     def get_entries(
-        self,
-        chemsys_formula,
-        sort_by_e_above_hull=False,
+        self, chemsys_formula, sort_by_e_above_hull=False,
     ):
         """
         Get a list of ComputedEntries or ComputedStructureEntries corresponding
@@ -390,8 +389,7 @@ class MPRester:
                 chemsys_formula=chemsys_formula,
                 all_fields=False,
                 fields=["entries"],
-                sort_field="energy_above_hull",
-                ascending=True,
+                sort_fields=["energy_above_hull"],
             ):
                 entries.extend(list(doc.entries.values()))
 
@@ -399,9 +397,7 @@ class MPRester:
 
         else:
             for doc in self.thermo.search_thermo_docs(
-                chemsys_formula=chemsys_formula,
-                all_fields=False,
-                fields=["entries"],
+                chemsys_formula=chemsys_formula, all_fields=False, fields=["entries"],
             ):
                 entries.extend(list(doc.entries.values()))
 
@@ -699,9 +695,7 @@ class MPRester:
         )
 
     def get_entries_in_chemsys(
-        self,
-        elements,
-        use_gibbs: Optional[int] = None,
+        self, elements, use_gibbs: Optional[int] = None,
     ):
         """
         Helper method to get a list of ComputedEntries in a chemical system.
@@ -853,8 +847,7 @@ class MPRester:
         has_reconstructed: Optional[bool] = None,
         has_props: Optional[List[str]] = None,
         theoretical: Optional[bool] = None,
-        sort_field: Optional[str] = None,
-        ascending: Optional[bool] = None,
+        sort_fields: Optional[List[str]] = None,
         num_chunks: Optional[int] = None,
         chunk_size: int = 1000,
         all_fields: bool = True,
@@ -927,8 +920,7 @@ class MPRester:
             has_reconstructed (bool): Whether the entry has any reconstructed surfaces.
             has_props: (List[str]): The calculated properties available for the material.
             theoretical: (bool): Whether the material is theoretical.
-            sort_field (str): Field used to sort results.
-            ascending (bool): Whether sorting should be in ascending order.
+            sort_fields (List[str]): Fields used to sort results. Prefixing with '-' will sort in descending order.
             num_chunks (int): Maximum number of chunks of data to yield. None will yield all possible.
             chunk_size (int): Number of data entries per chunk.
             all_fields (bool): Whether to return all fields in the document. Defaults to True.
@@ -987,8 +979,7 @@ class MPRester:
             has_reconstructed=has_reconstructed,
             has_props=has_props,
             theoretical=theoretical,
-            sort_field=sort_field,
-            ascending=ascending,
+            sort_fields=sort_fields,
             num_chunks=num_chunks,
             chunk_size=chunk_size,
             all_fields=all_fields,
