@@ -9,7 +9,7 @@ import json
 import platform
 import sys
 from json import JSONDecodeError
-from typing import Dict, Optional, List, Union, Generic, TypeVar
+from typing import Dict, Optional, List, Union, Generic, TypeVar, Sequence
 from urllib.parse import urljoin
 from os import environ
 import warnings
