@@ -1,4 +1,10 @@
 from pydantic import BaseModel, Field
+from typing import Dict
+
+try:
+    from typing import Literal  # type: ignore
+except ImportError:
+    from typing_extensions import Literal
 from datetime import datetime
 
 
@@ -7,11 +13,13 @@ class GeneralStoreDoc(BaseModel):
     Defines general store data
     """
 
-    kind: str = Field(None, description="Type of the data.")
+    kind: Literal["newsfeed", "seminar", "banner"] = Field(
+        None, description="Type of the data."
+    )
 
     markdown: str = Field(None, description="Markdown data.")
 
-    meta: str = Field(None, description="Metadata.")
+    meta: Dict = Field(None, description="Metadata.")
 
     last_updated: datetime = Field(
         description="Timestamp for when this document was last updated",
