@@ -8,10 +8,13 @@ class ChgcarDataDoc(BaseModel):
     Electron charge density for selected materials.
     """
 
-    fs_id: str = Field(None, description="Unique object ID for the charge density data.")
+    fs_id: str = Field(
+        None, description="Unique object ID for the charge density data."
+    )
 
     last_updated: datetime = Field(
-        None, description="Timestamp for the most recent update to the charge density data.",
+        None,
+        description="Timestamp for the most recent update to the charge density data.",
     )
 
     task_id: str = Field(
