@@ -17,8 +17,7 @@ class DielectricRester(BaseRester[DielectricDoc]):
         e_ionic: Optional[Tuple[float, float]] = None,
         e_electronic: Optional[Tuple[float, float]] = None,
         n: Optional[Tuple[float, float]] = None,
-        sort_field: Optional[str] = None,
-        ascending: Optional[bool] = None,
+        sort_fields: Optional[List[str]] = None,
         num_chunks: Optional[int] = None,
         chunk_size: int = 1000,
         all_fields: bool = True,
@@ -32,8 +31,7 @@ class DielectricRester(BaseRester[DielectricDoc]):
             e_ionic (Tuple[float,float]): Minimum and maximum ionic dielectric constant to consider.
             e_electronic (Tuple[float,float]): Minimum and maximum electronic dielectric constant to consider.
             n (Tuple[float,float]): Minimum and maximum refractive index to consider.
-            sort_field (str): Field used to sort results.
-            ascending (bool): Whether sorting should be in ascending order.
+            sort_fields (List[str]): Fields used to sort results. Prefix with '-' to sort in descending order.
             num_chunks (int): Maximum number of chunks of data to yield. None will yield all possible.
             chunk_size (int): Number of data entries per chunk.
             all_fields (bool): Whether to return all fields in the document. Defaults to True.
@@ -63,11 +61,10 @@ class DielectricRester(BaseRester[DielectricDoc]):
         if n:
             query_params.update({"n_min": n[0], "n_max": n[1]})
 
-        if sort_field:
-            query_params.update({"sort_field": sort_field})
-
-        if ascending is not None:
-            query_params.update({"ascending": ascending})
+        if sort_fields:
+            query_params.update(
+                {"sort_fields": ",".join([s.strip() for s in sort_fields])}
+            )
 
         query_params = {
             entry: query_params[entry]
