@@ -1,5 +1,5 @@
 from maggma.api.resource import ReadOnlyResource
-from mp_api.routes.magnetism.models import MagnetismDoc
+from emmet.core.magnetism import MagnetismDoc
 
 from maggma.api.query_operator import PaginationQuery, SortQuery, SparseFieldsQuery
 from mp_api.routes.magnetism.query_operators import MagneticQuery
@@ -13,7 +13,9 @@ def magnetism_resource(magnetism_store):
             MagneticQuery(),
             SortQuery(),
             PaginationQuery(),
-            SparseFieldsQuery(MagnetismDoc, default_fields=["task_id", "last_updated"]),
+            SparseFieldsQuery(
+                MagnetismDoc, default_fields=["material_id", "last_updated"]
+            ),
         ],
         tags=["Magnetism"],
         disable_validation=True,
