@@ -13,8 +13,6 @@ from maggma.api.query_operator import (
     NumericQuery,
 )
 
-from mp_api.core.settings import MAPISettings
-
 from mp_api.routes.materials.query_operators import (
     ElementsQuery,
     FormulaQuery,
@@ -25,8 +23,6 @@ from mp_api.routes.materials.query_operators import (
     FormulaAutoCompleteQuery,
 )
 
-from pymongo import MongoClient  # type: ignore
-
 
 def find_structure_resource(materials_store):
     resource = PostOnlyResource(
