@@ -2,7 +2,7 @@ from mp_api.core.client import BaseRester
 from emmet.core.provenance import ProvenanceDoc
 
 
-class ProvenanceRester(BaseRester):
+class ProvenanceRester(BaseRester[ProvenanceDoc]):
 
     suffix = "provenance"
     document_model = ProvenanceDoc  # type: ignore
