@@ -65,8 +65,7 @@ class SummaryRester(BaseRester[SummaryDoc]):
         has_reconstructed: Optional[bool] = None,
         has_props: Optional[List[str]] = None,
         theoretical: Optional[bool] = None,
-        sort_field: Optional[str] = None,
-        ascending: Optional[bool] = None,
+        sort_fields: Optional[List[str]] = None,
         num_chunks: Optional[int] = None,
         chunk_size: int = 1000,
         all_fields: bool = True,
@@ -139,8 +138,7 @@ class SummaryRester(BaseRester[SummaryDoc]):
             has_reconstructed (bool): Whether the entry has any reconstructed surfaces.
             has_props: (List[str]): The calculated properties available for the material.
             theoretical: (bool): Whether the material is theoretical.
-            sort_field (str): Field used to sort results.
-            ascending (bool): Whether sorting should be in ascending order.
+            sort_fields (List[str]): Fields used to sort results. Prefixing with '-' will sort in descending order.
             num_chunks (int): Maximum number of chunks of data to yield. None will yield all possible.
             chunk_size (int): Number of data entries per chunk.
             all_fields (bool): Whether to return all fields in the document. Defaults to True.
@@ -241,11 +239,10 @@ class SummaryRester(BaseRester[SummaryDoc]):
         if theoretical is not None:
             query_params.update({"theoretical": theoretical})
 
-        if sort_field:
-            query_params.update({"sort_field": sort_field})
-
-        if ascending is not None:
-            query_params.update({"ascending": ascending})
+        if sort_fields:
+            query_params.update(
+                {"sort_fields": ",".join([s.strip() for s in sort_fields])}
+            )
 
         query_params = {
             entry: query_params[entry]
