@@ -9,8 +9,7 @@ import typing
 resters = [ThermoRester()]
 
 excluded_params = [
-    "sort_field",
-    "ascending",
+    "sort_fields",
     "chunk_size",
     "num_chunks",
     "all_fields",
@@ -35,9 +34,7 @@ custom_field_tests = {
 }  # type: dict
 
 
-@pytest.mark.skipif(
-    os.environ.get("MP_API_KEY", None) is None, reason="No API key found."
-)
+@pytest.mark.skipif(os.environ.get("MP_API_KEY", None) is None, reason="No API key found.")
 @pytest.mark.parametrize("rester", resters)
 def test_client(rester):
     # Get specific search method
@@ -63,9 +60,7 @@ def test_client(rester):
                         param: (-100, 100),
                         "chunk_size": 1,
                         "num_chunks": 1,
-                        "fields": [
-                            project_field if project_field is not None else param
-                        ],
+                        "fields": [project_field if project_field is not None else param],
                     }
                 elif param_type is typing.Tuple[float, float]:
                     project_field = alt_name_dict.get(param, None)
@@ -73,9 +68,7 @@ def test_client(rester):
                         param: (-100.12, 100.12),
                         "chunk_size": 1,
                         "num_chunks": 1,
-                        "fields": [
-                            project_field if project_field is not None else param
-                        ],
+                        "fields": [project_field if project_field is not None else param],
                     }
                 elif param_type is bool:
                     project_field = alt_name_dict.get(param, None)
@@ -83,9 +76,7 @@ def test_client(rester):
                         param: False,
                         "chunk_size": 1,
                         "num_chunks": 1,
-                        "fields": [
-                            project_field if project_field is not None else param
-                        ],
+                        "fields": [project_field if project_field is not None else param],
                     }
                 elif param in custom_field_tests:
                     project_field = alt_name_dict.get(param, None)
@@ -93,9 +84,7 @@ def test_client(rester):
                         param: custom_field_tests[param],
                         "chunk_size": 1,
                         "num_chunks": 1,
-                        "fields": [
-                            project_field if project_field is not None else param
-                        ],
+                        "fields": [project_field if project_field is not None else param],
                     }
 
                 doc = search_method(**q)[0].dict()
@@ -103,15 +92,10 @@ def test_client(rester):
                     if sub_field in doc:
                         doc = doc[sub_field]
 
-                assert (
-                    doc[project_field if project_field is not None else param]
-                    is not None
-                )
+                assert doc[project_field if project_field is not None else param] is not None
 
 
 @pytest.mark.xfail(reason="Temporary until deployment")
 def test_get_phase_diagram_from_chemsys():
     # Test that a phase diagram is returned
-    assert isinstance(
-        ThermoRester().get_phase_diagram_from_chemsys("Fe-Mn-Pt"), PhaseDiagram
-    )
+    assert isinstance(ThermoRester().get_phase_diagram_from_chemsys("Fe-Mn-Pt"), PhaseDiagram)
